MBElevatedButton class

Inheritance

Constructors

MBElevatedButton({Key? key, double? elevation, double? roundness, Color? buttonColor, Color? textColor, required String text, required dynamic onTapFunction()})
Without text and onTapFunction a MBElevatedButton doesn't exist.
const

Properties

buttonColor → Color?
buttonColor is the color of the MBElevatedButton. By default it is set to Colors.blue
final
elevation → double?
elevation is the vertical distance from the Scaffold body of your application to the MBElevatedButton widget. A minimal amount with respect to screen size is recommended for great output.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onTapFunction → dynamic Function()
onTapFunction is the function which MBElevatedButton has to do when the MBButton is tapped. This is also a required field, so there is no default value to it.
final
roundness → double?
roundness is the smoothness of the MBElevatedButton's edge. The variable type of roundness is double. By default it is set to zero
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
text is the value of the text which is displayed on MBElevatedButton. This is a required field, so there is no default value to it.
final
textColor → Color?
textColor is the color of the text which is displayed on MBElevatedButton. By default it is set to Colors.white
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _MBElevatedButtonState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited